/*

Copyright (C) 2000 - 2003 Christian Kreibich <christian@whoop.org>.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies of the Software and its documentation and acknowledgment shall be
given in the documentation and software packages that this Software was
used.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*/
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <nd.h>
#include <nd_gui.h>
#include <nd_tp.h>
#include <nd_packet_iterator.h>


gboolean
nd_pit_init(LND_PacketIterator *pit,
	    LND_Trace *trace)
{
  return nd_pit_init_mode(pit, trace, trace->iterator_mode);
}


gboolean
nd_pit_init_mode(LND_PacketIterator *pit,
		 LND_Trace *trace,
		 LND_PacketIteratorMode mode)
{
  char key[MAXPATHLEN];
  off_t offset;
  gboolean result;

  switch (pit->mode)
    {
    case LND_PACKET_IT_AREA_RW:
    case LND_PACKET_IT_AREA_R:
      /* Store current start offset */

      g_snprintf(key, MAXPATHLEN, "pit-start-offset-%p", pit);
      offset = libnd_tpm_map_loc_to_offset(trace->tpm, &trace->tpm->current->start);
      libnd_trace_set_data(trace, key, GINT_TO_POINTER(offset));
      break;
      
    default:
      /* No extra work necessary ... */
    }

  if (!(result = libnd_pit_init_mode(pit, trace, mode)))
    nd_dialog_message(_("Iteration Problem"),
		      _("An error occurred when initializing the packet iterator."),
		      FALSE);

    return result;
}


LND_Packet *
nd_pit_get(LND_PacketIterator *pit)
{
  return libnd_pit_get(pit);
}


LND_Packet *           
nd_pit_next(LND_PacketIterator *pit)
{
  LND_Packet *packet = libnd_pit_next(pit);
  char        key[MAXPATHLEN];

  if (! packet)
    {
      switch (pit->mode)
	{
	case LND_PACKET_IT_AREA_RW:
	case LND_PACKET_IT_AREA_R:
	  {
	    off_t         offset;
	    LND_TraceLoc  loc;
	    
	    /* Restore old start offset */
	    g_snprintf(key, MAXPATHLEN, "pit-start-offset-%p", pit);
	    offset = GPOINTER_TO_INT(libnd_trace_del_data(pit->trace, key));
	    
	    libnd_tpm_map_offset_to_loc(pit->trace->tpm, offset, &loc);
	    libnd_tpm_goto_loc(pit->trace->tpm, &loc);
	    
	    /* The libnetdude event notifiers cause this to call back into
	     * Netdude to update the GUI ...
	     */
	    libnd_tpm_load_packets(pit->trace->tpm);	    
	  }
	  break;
	  
	default:
	  nd_gui_list_update(pit->trace);
	}
    }
  
  return packet;
}
